@@ -1,6 +1,6 @@
 =head1 NAME
 
-SVG::TrafficLight
+SVG::TrafficLight - Perl extension to produce SVG diagrams of traffic lights.
 
 =head1 DESCRIPTION
 
@@ -30,7 +30,7 @@ use warnings;
 use Moose;
 use SVG;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 =head1 ATTRIBUTES AND METHODS
 
